package cn.com.infosec.jce;

import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1Set;
import cn.com.infosec.asn1.DERConstructedSequence;
import cn.com.infosec.asn1.DERConstructedSet;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERInputStream;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.pkcs.ContentInfo;
import cn.com.infosec.asn1.pkcs.IssuerAndSerialNumber;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.SignedData;
import cn.com.infosec.asn1.pkcs.SignerInfo;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.CertificateList;
import cn.com.infosec.asn1.x509.X509CertificateStructure;
import cn.com.infosec.asn1.x509.X509Name;
import cn.com.infosec.jce.provider.X509CRLObject;
import cn.com.infosec.jce.provider.X509CRLObjectFX;
import cn.com.infosec.jce.provider.X509CertificateObject;
import cn.com.infosec.jce.provider.X509CertificateObjectFX;
import cn.com.infosec.jce.provider.fastparser.DerUtil;
import cn.com.infosec.jce.provider.fastparser.FX509Certificate;
import cn.com.infosec.jce.provider.fastparser.FastPkcs7;
import cn.com.infosec.jce.provider.fastparser.Item;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.NoSuchAlgorithmException;
import java.security.PrivateKey;
import java.security.Signature;
import java.security.cert.CRL;
import java.security.cert.CRLException;
import java.security.cert.Certificate;
import java.security.cert.X509CRL;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Set;

public class PKCS7SignedData implements PKCSObjectIdentifiers {
   static final String ID_MD5 = "1.2.840.113549.2.5";
   static final String ID_MD2 = "1.2.840.113549.2.2";
   static final String ID_SHA1 = "1.3.14.3.2.26";
   static final String ID_RSA = "1.2.840.113549.1.1.1";
   static final String ID_DSA = "1.2.840.10040.4.1";
   static final String ID_SHA224 = "2.16.840.1.101.3.4.2.4";
   static final String ID_SHA256 = "2.16.840.1.101.3.4.2.1";
   static final String ID_SHA384 = "2.16.840.1.101.3.4.2.2";
   static final String ID_SHA512 = "2.16.840.1.101.3.4.2.3";
   static final String ID_RC4 = "1.2.840.113549.3.4";
   static final String ID_DES = "1.3.14.3.2.7";
   static final String ID_DESEDE = "1.2.840.113549.3.7";
   static final String ID_RC2 = "1.2.840.113549.3.2";
   static final String ID_AES = "2.16.840.1.101.3.4.2";
   static final int MD5 = 1;
   static final int MD2 = 2;
   static final int SHA1 = 3;
   static final int RSA = 4;
   static final int DSA = 5;
   static final int SHA224 = 6;
   static final int SHA256 = 7;
   static final int SHA384 = 8;
   static final int SHA512 = 9;
   static final int RC4 = 10;
   static final int DES = 11;
   static final int DESEDE = 12;
   static final int RC2 = 13;
   static final int AES = 14;
   static String[] algArray = new String[]{"MD5", "MD2", "SHA1", "RSA", "DSA", "SHA224", "SHA256", "SHA384", "SHA512", "RC4", "DES", "DESEDE", "RC2", "AES"};
   static String[] algArray2 = new String[]{"MD5", "MD2", "SHA1", "RSA", "DSA", "SHA224", "SHA256", "SHA384", "SHA512", "RC4", "DES", "3DES", "RC2", "AES"};
   static HashMap algmap;
   int version;
   int signerversion;
   Set digestalgos;
   Collection certs;
   Collection crls;
   X509Certificate signCert;
   byte[] digest;
   String digestAlgorithm;
   String digestEncryptionAlgorithm;
   Signature sig;
   transient PrivateKey privKey;
   byte[] contentData;
   byte[] signCertTBS;
   DERObject[] certsEncoded;
   Hashtable isAndsns;
   final String ID_PKCS7_DATA;
   final String ID_PKCS7_SIGNED_DATA;
   byte[] bsPKCS7;
   FastPkcs7 fxPKCS7;
   String provider;

   static {
      (algmap = new HashMap()).put("1.2.840.113549.2.5", "MD5");
      algmap.put("1.2.840.113549.2.2", "MD2");
      algmap.put("1.3.14.3.2.26", "SHA1");
      algmap.put("1.2.840.113549.1.1.1", "RSA");
      algmap.put("1.2.840.10040.4.1", "DSA");
      algmap.put("2.16.840.1.101.3.4.2.4", "SHA224");
      algmap.put("2.16.840.1.101.3.4.2.1", "SHA256");
      algmap.put("2.16.840.1.101.3.4.2.2", "SHA384");
      algmap.put("2.16.840.1.101.3.4.2.3", "SHA512");
      algmap.put("1.2.840.113549.3.4", "RC4");
      algmap.put("1.3.14.3.2.7", "DES");
      algmap.put("1.2.840.113549.3.7", "DESEDE");
      algmap.put("1.2.840.113549.3.2", "RC2");
      algmap.put("2.16.840.1.101.3.4.2", "AES");
   }

   public PKCS7SignedData() {
      this.ID_PKCS7_DATA = "1.2.840.113549.1.7.1";
      this.ID_PKCS7_SIGNED_DATA = "1.2.840.113549.1.7.2";
      this.bsPKCS7 = null;
      this.fxPKCS7 = null;
      this.provider = "";
   }

   public PKCS7SignedData(byte[] in) {
      this(in, "INFOSEC");
   }

   public PKCS7SignedData(byte[] in, String provider) {
      this.ID_PKCS7_DATA = "1.2.840.113549.1.7.1";
      this.ID_PKCS7_SIGNED_DATA = "1.2.840.113549.1.7.2";
      this.bsPKCS7 = null;
      this.fxPKCS7 = null;
      this.provider = "";
      FastPkcs7 var3;
      FastPkcs7 var10007 = var3 = new FastPkcs7;
      var3.<init>();
      this.fxPKCS7 = var3;
      var10007.pkcs7SignedData(in);
      this.provider = provider;
      this.bsPKCS7 = in;
      ArrayList var16 = this.fxPKCS7.getCerts();
      this.certs = new ArrayList();
      this.certsEncoded = new DERObject[var16.size()];

      int var6;
      int var7;
      byte[] var8;
      PKCS7SignedData var10000;
      for(int var4 = 0; var4 < var16.size(); ++var4) {
         var10000 = this;
         Item var5;
         var8 = new byte[var7 = (var5 = (Item)var16.get(var4)).length + (var6 = var5.tagsize)];
         System.arraycopy(this.bsPKCS7, var5.offset - var6, var8, 0, var7);
         this.certs.add(new X509CertificateObjectFX(var8));
         ASN1InputStream var10001 = new ASN1InputStream(new ByteArrayInputStream(var8));

         IOException var28;
         label74: {
            boolean var29;
            ASN1Sequence var30;
            try {
               var30 = (ASN1Sequence)var10001.readObject();
            } catch (IOException var12) {
               var28 = var12;
               var29 = false;
               break label74;
            }

            ASN1Sequence var24 = var30;

            try {
               var10000.certsEncoded[var4] = var24;
               continue;
            } catch (IOException var11) {
               var28 = var11;
               var29 = false;
            }
         }

         IOException var13 = var28;
         throw new RuntimeException(var13.getMessage());
      }

      ArrayList var25 = this.fxPKCS7.getCrls();
      this.crls = new ArrayList();

      for(int var17 = 0; var17 < var25.size(); ++var17) {
         var10000 = this;
         Item var21;
         var8 = new byte[var7 = (var21 = (Item)var25.get(var17)).length + (var6 = var21.tagsize)];
         System.arraycopy(this.bsPKCS7, var21.offset - var6, var8, 0, var7);

         try {
            var10000.crls.add(new X509CRLObjectFX(var8));
         } catch (CRLException var10) {
            var10.printStackTrace();
         }
      }

      byte[] var10002 = in;
      Item in1 = this.fxPKCS7.getSignCert();
      in = DerUtil.getItemDataAndTag(this.bsPKCS7, in1);
      X509CertificateObjectFX var19;
      X509CertificateObjectFX var10006 = var19 = new X509CertificateObjectFX;
      var10006.<init>(in);
      this.signCert = var10006;
      this.signCertTBS = var19.getTBSCertificate();
      Item var10003 = this.fxPKCS7.getSignCert();
      int in2;
      byte[] var20 = new byte[in2 = var10003.length];
      System.arraycopy(var10002, var10003.offset, var20, 0, in2);
      (new FX509Certificate()).parse(var20, 0, in2);
      ArrayList var22 = this.fxPKCS7.getDigestAlgorithms();
      this.digestalgos = new HashSet();

      for(in2 = 0; in2 < var22.size(); ++in2) {
         Item var23 = (Item)var22.get(in2);
         var20 = DerUtil.getItemDataAndTag(this.bsPKCS7, var23);
         ASN1InputStream var31 = new ASN1InputStream(var20);
         ASN1Sequence var26 = null;

         label39: {
            ASN1Sequence var32;
            try {
               var32 = (ASN1Sequence)var31.readObject();
            } catch (IOException var9) {
               var9.printStackTrace();
               break label39;
            }

            var26 = var32;
         }

         DERObjectIdentifier var27 = (DERObjectIdentifier)var26.getObjectAt(0);
         this.digestalgos.add(var27.getId());
      }

      this.version = this.fxPKCS7.getVersion();
      this.signerversion = this.fxPKCS7.getSignInfoVersion();
      in1 = this.fxPKCS7.getRawData();
      this.contentData = DerUtil.getItemData(this.bsPKCS7, in1);
      in1 = this.fxPKCS7.getDigest();
      this.digest = DerUtil.getItemData(this.bsPKCS7, in1);
      this.digestAlgorithm = this.fxPKCS7.getDigestAlgorithm();
      this.digestEncryptionAlgorithm = this.fxPKCS7.getDigestEncryptionAlgorithm();
      Signature in3;
      Signature var33 = in3 = Signature.getInstance(this.getDigestAlgorithm(), provider);
      this.sig = in3;
      var33.initVerify(this.signCert.getPublicKey());
   }

   public PKCS7SignedData(PrivateKey privKey, Certificate[] certChain, String hashAlgorithm) {
      this(privKey, certChain, hashAlgorithm, "INFOSEC");
   }

   public PKCS7SignedData(PrivateKey privKey, Certificate[] certChain, String hashAlgorithm, String provider) {
      this(privKey, certChain, (CRL[])null, hashAlgorithm, provider);
   }

   public PKCS7SignedData(PrivateKey privKey, Certificate[] certChain, CRL[] crlList, String hashAlgorithm, String provider) {
      this.ID_PKCS7_DATA = "1.2.840.113549.1.7.1";
      this.ID_PKCS7_SIGNED_DATA = "1.2.840.113549.1.7.2";
      this.bsPKCS7 = null;
      this.fxPKCS7 = null;
      this.provider = "";
      this.privKey = privKey;
      if (hashAlgorithm.equals("MD5")) {
         this.digestAlgorithm = "1.2.840.113549.2.5";
      } else if (hashAlgorithm.equals("MD2")) {
         this.digestAlgorithm = "1.2.840.113549.2.2";
      } else if (hashAlgorithm.equals("SHA")) {
         this.digestAlgorithm = "1.3.14.3.2.26";
      } else if (hashAlgorithm.equals("SHA1")) {
         this.digestAlgorithm = "1.3.14.3.2.26";
      } else if (hashAlgorithm.equals("SHA224")) {
         this.digestAlgorithm = "2.16.840.1.101.3.4.2.4";
      } else if (hashAlgorithm.equals("SHA256")) {
         this.digestAlgorithm = "2.16.840.1.101.3.4.2.1";
      } else if (hashAlgorithm.equals("ID_SHA384")) {
         this.digestAlgorithm = "2.16.840.1.101.3.4.2.2";
      } else {
         if (!hashAlgorithm.equals("ID_SHA512")) {
            throw new NoSuchAlgorithmException("Unknown Hash Algorithm " + hashAlgorithm);
         }

         this.digestAlgorithm = "2.16.840.1.101.3.4.2.3";
      }

      this.signerversion = 1;
      this.version = 1;
      this.certs = new ArrayList();
      this.crls = new ArrayList();
      HashSet hashAlgorithm1;
      HashSet var10002 = hashAlgorithm1 = new HashSet;
      hashAlgorithm1.<init>();
      this.digestalgos = hashAlgorithm1;
      var10002.add(this.digestAlgorithm);
      this.signCert = (X509Certificate)certChain[0];

      for(int hashAlgorithm2 = 0; hashAlgorithm2 < certChain.length; ++hashAlgorithm2) {
         this.certs.add(certChain[hashAlgorithm2]);
      }

      if (crlList != null) {
         for(int certChain1 = 0; certChain1 < crlList.length; ++certChain1) {
            this.crls.add(crlList[certChain1]);
         }
      }

      if ((this.digestEncryptionAlgorithm = privKey.getAlgorithm()).equals("RSA")) {
         this.digestEncryptionAlgorithm = "1.2.840.113549.1.1.1";
      } else {
         if (!this.digestEncryptionAlgorithm.equals("DSA")) {
            throw new NoSuchAlgorithmException("Unknown Key Algorithm " + this.digestEncryptionAlgorithm);
         }

         this.digestEncryptionAlgorithm = "1.2.840.10040.4.1";
      }

      Signature certChain2;
      Signature var10000 = certChain2 = Signature.getInstance(this.getDigestAlgorithm(), provider);
      this.sig = certChain2;
      var10000.initSign(privKey);
   }

   private static String getAlgName(String oid) {
      String var1 = null;
      if (algmap.containsKey(oid)) {
         var1 = algmap.get(oid).toString();
      }

      return var1;
   }

   private static String getAlgName(int alg) {
      return algArray[alg - 1];
   }

   private static int getAlgID(String alg) {
      byte var1 = 0;
      String[] var2;
      int var10000 = (var2 = algArray2).length;
      byte var3 = 0;
      if (var10000 > 0 && alg.equalsIgnoreCase(var2[var3])) {
         var1 = 1;
      }

      return var1;
   }

   private DERObject getIssuer(byte[] enc) {
      IOException var10000;
      label32: {
         boolean var10001;
         DERConstructedSequence var8;
         try {
            var8 = (DERConstructedSequence)(new DERInputStream(new ByteArrayInputStream(enc))).readObject();
         } catch (IOException var4) {
            var10000 = var4;
            var10001 = false;
            break label32;
         }

         DERConstructedSequence var5 = var8;

         boolean var9;
         try {
            var9 = var8.getObjectAt(0) instanceof DERTaggedObject;
         } catch (IOException var3) {
            var10000 = var3;
            var10001 = false;
            break label32;
         }

         byte enc1;
         if (var9) {
            enc1 = 3;
         } else {
            enc1 = 2;
         }

         try {
            return (DERObject)var5.getObjectAt(enc1);
         } catch (IOException var2) {
            var10000 = var2;
            var10001 = false;
         }
      }

      IOException var6 = var10000;
      throw new Error("IOException reading from ByteArray: " + var6);
   }

   public void PKCS7SignedData2(byte[] in, String provider) {
      DERInputStream var10000 = new DERInputStream(new ByteArrayInputStream(in));

      DERObject var19;
      try {
         var19 = var10000.readObject();
      } catch (IOException var7) {
         throw new SecurityException("can't decode PKCS7SignedData object");
      }

      DERObject in1 = var19;
      if (var19 instanceof DERConstructedSequence) {
         ContentInfo in2;
         if (!(in2 = ContentInfo.getInstance(in1)).getContentType().equals(PKCSObjectIdentifiers.signedData)) {
            throw new SecurityException("Not a valid PKCS#7 signed-data object - wrong header " + in2.getContentType().getId());
         } else {
            SignedData var3 = SignedData.getInstance(in2.getContent());
            this.certs = new ArrayList();
            Enumeration in3;
            if (var3.getCertificates() != null) {
               in3 = ASN1Set.getInstance(var3.getCertificates()).getObjects();

               while(in3.hasMoreElements()) {
                  this.certs.add(new X509CertificateObject(X509CertificateStructure.getInstance(in3.nextElement())));
               }
            }

            this.crls = new ArrayList();
            if (var3.getCRLs() != null) {
               in3 = ASN1Set.getInstance(var3.getCRLs()).getObjects();

               while(in3.hasMoreElements()) {
                  this.crls.add(new X509CRLObject(CertificateList.getInstance(in3.nextElement())));
               }
            }

            this.version = var3.getVersion().getValue().intValue();
            DEREncodable in4;
            if ((in4 = var3.getContentInfo().getContent()) != null) {
               this.contentData = ((ASN1OctetString)in4).getOctets();
            } else {
               this.contentData = null;
            }

            this.digestalgos = new HashSet();
            Enumeration var4 = var3.getDigestAlgorithms().getObjects();

            while(var4.hasMoreElements()) {
               DERObjectIdentifier in5 = (DERObjectIdentifier)((DERConstructedSequence)var4.nextElement()).getObjectAt(0);
               this.digestalgos.add(in5.getId());
            }

            DERConstructedSet in6;
            if ((in6 = (DERConstructedSet)var3.getSignerInfos()).getSize() != 1) {
               throw new SecurityException("This PKCS#7 object has multiple SignerInfos - only one is supported at this time");
            } else {
               SignerInfo in7;
               SignerInfo var10001 = in7 = SignerInfo.getInstance(in6.getObjectAt(0));
               this.signerversion = in7.getVersion().getValue().intValue();
               IssuerAndSerialNumber var14;
               BigInteger var18 = (var14 = var10001.getIssuerAndSerialNumber()).getCertificateSerialNumber().getValue();
               X509Principal var5;
               var5 = new X509Principal.<init>(var14.getName());
               Iterator var16 = this.certs.iterator();

               while(var16.hasNext()) {
                  X509Certificate var6;
                  if (var18.equals((var6 = (X509Certificate)var16.next()).getSerialNumber()) && var5.equals(var6.getIssuerDN())) {
                     this.signCert = var6;
                     break;
                  }
               }

               if (this.signCert != null) {
                  this.digestAlgorithm = in7.getDigestAlgorithm().getObjectId().getId();
                  this.digest = in7.getEncryptedDigest().getOctets();
                  this.digestEncryptionAlgorithm = in7.getDigestEncryptionAlgorithm().getObjectId().getId();
                  Signature in8;
                  Signature var20 = in8 = Signature.getInstance(this.getDigestAlgorithm(), provider);
                  this.sig = in8;
                  var20.initVerify(this.signCert.getPublicKey());
               } else {
                  throw new SecurityException("Can't find signing certificate with serial " + var18.toString(16));
               }
            }
         }
      } else {
         throw new SecurityException("Not a valid PKCS#7 object - not a sequence");
      }
   }

   public String getDigestAlgorithm() {
      String var1;
      String var10000 = var1 = this.digestAlgorithm;
      String var2 = this.digestEncryptionAlgorithm;
      if (var10000.equals("1.2.840.113549.2.5")) {
         var1 = "MD5";
      } else if (this.digestAlgorithm.equals("1.2.840.113549.2.2")) {
         var1 = "MD2";
      } else if (this.digestAlgorithm.equals("1.3.14.3.2.26")) {
         var1 = "SHA1";
      } else if (this.digestAlgorithm.equals("2.16.840.1.101.3.4.2.4")) {
         var1 = "SHA224";
      } else if (this.digestAlgorithm.equals("2.16.840.1.101.3.4.2.1")) {
         var1 = "SHA256";
      } else if (this.digestAlgorithm.equals("2.16.840.1.101.3.4.2.2")) {
         var1 = "SHA384";
      } else if (this.digestAlgorithm.equals("2.16.840.1.101.3.4.2.3")) {
         var1 = "SHA512";
      }

      if (this.digestEncryptionAlgorithm.equals("1.2.840.113549.1.1.1")) {
         var2 = "RSA";
      } else if (this.digestEncryptionAlgorithm.equals("1.2.840.10040.4.1")) {
         var2 = "DSA";
      }

      return var1 + "with" + var2;
   }

   public void reset() {
      Exception var10000;
      label28: {
         boolean var10001;
         PrivateKey var7;
         try {
            var7 = this.privKey;
         } catch (Exception var5) {
            var10000 = var5;
            var10001 = false;
            break label28;
         }

         PrivateKey var1 = var7;
         if (var7 == null) {
            try {
               this.sig.initVerify(this.signCert.getPublicKey());
            } catch (Exception var4) {
               var10000 = var4;
               var10001 = false;
               break label28;
            }
         } else {
            try {
               this.sig.initSign(var1);
            } catch (Exception var3) {
               var10000 = var3;
               var10001 = false;
               break label28;
            }
         }

         try {
            return;
         } catch (Exception var2) {
            var10000 = var2;
            var10001 = false;
         }
      }

      Exception var6 = var10000;
      throw new RuntimeException(var6.toString());
   }

   public Certificate[] getCertificates() {
      return (X509Certificate[])this.certs.toArray(new X509Certificate[0]);
   }

   public Collection getCRLs() {
      return this.crls;
   }

   public X509Certificate getSigningCertificate() {
      return this.signCert;
   }

   public int getVersion() {
      return this.version;
   }

   public int getSigningInfoVersion() {
      return this.signerversion;
   }

   public byte[] getContentData() {
      return this.contentData;
   }

   public byte[] getSignCertTBS() {
      return this.signCertTBS;
   }

   public DERObject[] getCertEncoded() {
      return this.certsEncoded;
   }

   public void update(byte buf) {
      this.sig.update(buf);
   }

   public void update(byte[] buf, int off, int len) {
      this.sig.update(buf, off, len);
   }

   public boolean verify() {
      return this.sig.verify(this.digest);
   }

   public byte[] getEncoded() {
      return this.getEncoded((byte[])null);
   }

   public byte[] getEncoded(byte[] _contentData) {
      Exception var10000;
      label218: {
         boolean var10001;
         byte[] var46;
         try {
            var46 = this.digest;
         } catch (Exception var34) {
            var10000 = var34;
            var10001 = false;
            break label218;
         }

         if (var46 == null) {
            try {
               this.digest = this.sig.sign();
            } catch (Exception var33) {
               var10000 = var33;
               var10001 = false;
               break label218;
            }
         }

         PKCS7SignedData var47;
         DERConstructedSet var48;
         try {
            var47 = this;
            var48 = new DERConstructedSet;
         } catch (Exception var32) {
            var10000 = var32;
            var10001 = false;
            break label218;
         }

         DERConstructedSet var2 = var48;

         Iterator var49;
         try {
            var48.<init>();
            var49 = var47.digestalgos.iterator();
         } catch (Exception var31) {
            var10000 = var31;
            var10001 = false;
            break label218;
         }

         Iterator var3 = var49;

         label201:
         while(true) {
            boolean var50;
            try {
               var50 = var3.hasNext();
            } catch (Exception var29) {
               var10000 = var29;
               var10001 = false;
               break;
            }

            if (!var50) {
               DERConstructedSequence var53;
               try {
                  var46 = _contentData;
                  var53 = new DERConstructedSequence;
               } catch (Exception var28) {
                  var10000 = var28;
                  var10001 = false;
                  break;
               }

               DERConstructedSequence var41;
               DERConstructedSequence var10002 = var41 = var53;

               try {
                  var10002.<init>();
                  var53.addObject(new DERObjectIdentifier("1.2.840.113549.1.7.1"));
               } catch (Exception var27) {
                  var10000 = var27;
                  var10001 = false;
                  break;
               }

               DERConstructedSequence var56;
               if (var46 != null) {
                  DEROctetString var57;
                  try {
                     var56 = var41;
                     var57 = new DEROctetString;
                  } catch (Exception var26) {
                     var10000 = var26;
                     var10001 = false;
                     break;
                  }

                  DEROctetString var4 = var57;

                  try {
                     var57.<init>(_contentData);
                     var56.addObject(new DERTaggedObject(0, var4));
                  } catch (Exception var25) {
                     var10000 = var25;
                     var10001 = false;
                     break;
                  }
               }

               try {
                  var47 = this;
                  var48 = new DERConstructedSet;
               } catch (Exception var24) {
                  var10000 = var24;
                  var10001 = false;
                  break;
               }

               DERConstructedSet _contentData1 = var48;

               try {
                  var48.<init>();
                  var49 = var47.certs.iterator();
               } catch (Exception var23) {
                  var10000 = var23;
                  var10001 = false;
                  break;
               }

               Iterator var42 = var49;

               while(true) {
                  try {
                     var50 = var42.hasNext();
                  } catch (Exception var21) {
                     var10000 = var21;
                     var10001 = false;
                     break label201;
                  }

                  if (!var50) {
                     try {
                        var47 = this;
                        var53 = new DERConstructedSequence;
                     } catch (Exception var20) {
                        var10000 = var20;
                        var10001 = false;
                        break label201;
                     }

                     var10002 = var53;
                     DERConstructedSequence var10003 = var53;
                     DERConstructedSequence var43;
                     DERConstructedSequence var10004 = var43 = var53;

                     byte[] var10005;
                     try {
                        var43.<init>();
                        var43.addObject(new DERInteger(this.signerversion));
                        var10005 = this.signCert.getIssuerX500Principal().getEncoded();
                     } catch (Exception var19) {
                        var10000 = var19;
                        var10001 = false;
                        break label201;
                     }

                     byte[] var5 = var10005;

                     ASN1Sequence var58;
                     try {
                        var58 = (ASN1Sequence)(new ASN1InputStream(var5)).readObject();
                     } catch (Exception var18) {
                        var10000 = var18;
                        var10001 = false;
                        break label201;
                     }

                     ASN1Sequence var44 = var58;

                     try {
                        var10004.addObject(new IssuerAndSerialNumber(new X509Name(var44), new DERInteger(this.signCert.getSerialNumber())));
                        var10003.addObject(new AlgorithmIdentifier(new DERObjectIdentifier(this.digestAlgorithm), (DEREncodable)null));
                        var10002.addObject(new AlgorithmIdentifier(new DERObjectIdentifier(this.digestEncryptionAlgorithm), (DEREncodable)null));
                        var53.addObject(new DEROctetString(this.digest));
                        var53 = new DERConstructedSequence;
                     } catch (Exception var17) {
                        var10000 = var17;
                        var10001 = false;
                        break label201;
                     }

                     DERConstructedSequence var45;
                     var10002 = var45 = var53;

                     int var59;
                     try {
                        var45.<init>();
                        var45.addObject(new DERInteger(this.version));
                        var45.addObject(var2);
                        var10002.addObject(var41);
                        var53.addObject(new DERTaggedObject(false, 0, _contentData1));
                        var59 = var47.crls.size();
                     } catch (Exception var16) {
                        var10000 = var16;
                        var10001 = false;
                        break label201;
                     }

                     if (var59 > 0) {
                        try {
                           var47 = this;
                           var48 = new DERConstructedSet;
                        } catch (Exception var15) {
                           var10000 = var15;
                           var10001 = false;
                           break label201;
                        }

                        DERConstructedSet var35 = var48;

                        try {
                           var48.<init>();
                           var49 = var47.crls.iterator();
                        } catch (Exception var14) {
                           var10000 = var14;
                           var10001 = false;
                           break label201;
                        }

                        Iterator _contentData2 = var49;

                        while(true) {
                           try {
                              var50 = _contentData2.hasNext();
                           } catch (Exception var12) {
                              var10000 = var12;
                              var10001 = false;
                              break label201;
                           }

                           if (!var50) {
                              try {
                                 var45.addObject(new DERTaggedObject(false, 1, var35));
                                 break;
                              } catch (Exception var11) {
                                 var10000 = var11;
                                 var10001 = false;
                                 break label201;
                              }
                           }

                           try {
                              var35.addObject((new DERInputStream(new ByteArrayInputStream(((X509CRL)_contentData2.next()).getEncoded()))).readObject());
                           } catch (Exception var13) {
                              var10000 = var13;
                              var10001 = false;
                              break label201;
                           }
                        }
                     }

                     try {
                        var56 = var45;
                        var48 = new DERConstructedSet;
                     } catch (Exception var10) {
                        var10000 = var10;
                        var10001 = false;
                        break label201;
                     }

                     DERConstructedSet var51 = var48;
                     DERConstructedSet var52 = var48;

                     try {
                        var52.<init>();
                        var51.addObject(var43);
                        var56.addObject(var48);
                        var56 = new DERConstructedSequence;
                     } catch (Exception var9) {
                        var10000 = var9;
                        var10001 = false;
                        break label201;
                     }

                     var53 = var56;
                     DERConstructedSequence var36;
                     var10002 = var36 = var56;

                     ByteArrayOutputStream var62;
                     try {
                        var10002.<init>();
                        var53.addObject(new DERObjectIdentifier("1.2.840.113549.1.7.2"));
                        var56.addObject(new DERTaggedObject(0, var45));
                        var62 = new ByteArrayOutputStream;
                     } catch (Exception var8) {
                        var10000 = var8;
                        var10001 = false;
                        break label201;
                     }

                     ByteArrayOutputStream _contentData3;
                     ByteArrayOutputStream var60 = _contentData3 = var62;

                     DEROutputStream var61;
                     try {
                        var60.<init>();
                        var61 = new DEROutputStream;
                     } catch (Exception var7) {
                        var10000 = var7;
                        var10001 = false;
                        break label201;
                     }

                     DEROutputStream var54 = var61;
                     DEROutputStream var55 = var61;

                     try {
                        var55.<init>(_contentData3);
                        var54.writeObject(var36);
                        var61.close();
                        return var62.toByteArray();
                     } catch (Exception var6) {
                        var10000 = var6;
                        var10001 = false;
                        break label201;
                     }
                  }

                  try {
                     _contentData1.addObject((new DERInputStream(new ByteArrayInputStream(((X509Certificate)var42.next()).getEncoded()))).readObject());
                  } catch (Exception var22) {
                     var10000 = var22;
                     var10001 = false;
                     break label201;
                  }
               }
            }

            try {
               var2.addObject(new AlgorithmIdentifier(new DERObjectIdentifier((String)var3.next()), (DEREncodable)null));
            } catch (Exception var30) {
               var10000 = var30;
               var10001 = false;
               break;
            }
         }
      }

      Exception var37 = var10000;
      throw new RuntimeException(var37.toString());
   }
}
